=======
tsfresh
=======

This is the documentation of **tsfresh**.

tsfresh is a python package that is used to automatically calculate a huge number of time series characteristics, the
so called features.
Further the package contains methods to evaluate the explaining power and importance of such characteristics for
regression or classification tasks.


Contents
========

The following chapters will explain the tsfresh package in detail:

.. toctree::
   :maxdepth: 1

   Introduction <text/introduction>
   Quick Start <text/quick_start>
   Module Reference <api/modules>
   Data Formats <text/data_formats>
   Feature Naming <text/feature_naming>
   scikit-learn Transformers <text/sklearn_transformers>
   Feature Filtering <text/feature_filtering>
   How to write custom Feature Calculators <text/how_to_add_custom_feature>
   Authors <authors>
   License <license>
   Changelog <changes>
   How to contribute <text/how_to_contribute>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
